@@ -32,9 +32,11 @@
 #include "classStore.h"
 #include "context.h"
 #include "core.h"
+#include "dp8390d.h"
 #include "fdc.h"
 #include "heap.h"
 #include "interfaceStore.h"
+#include "loopback.h"
 #include "mps.h"
 #include "partition.h"
 #include "rtc.h"
@@ -60,6 +62,7 @@ namespace
     Pic*            pic;
     Mps*            mps;
     Apic*           apic;
+    u8              loopbackBuffer[64 * 1024];
 };
 
 const int Page::SIZE = 4096;
@@ -227,6 +230,10 @@ int esInit(IInterface** nameSpace)
     binding->release();
     device->release();
 
+    // Create network name space
+    IContext* network = root->createSubcontext("network");
+    network->release();
+
     // Create class store
     classStore = static_cast<IClassStore*>(new ClassStore);
     binding = root->bind("class", classStore);
@@ -291,6 +298,14 @@ int esInit(IInterface** nameSpace)
     root->bind("device/soundInput", static_cast<IStream*>(&sb16->inputLine));
     root->bind("device/soundOutput", static_cast<IStream*>(&sb16->outputLine));
 
+    // Register the loopback interface
+    Loopback* loopback = new Loopback(loopbackBuffer, sizeof loopbackBuffer);
+    device->bind("loopback", static_cast<IStream*>(loopback));
+
+    // Register the Ethernet interface
+    Dp8390d* ne2000 = new Dp8390d(0xc100, 10);
+    device->bind("ethernet", static_cast<IStream*>(ne2000));
+
     Process::initialize();
 
     return 0;
@@ -380,3 +395,8 @@ Reflect::Interface& getInterface(const Guid& iid)
 {
     return interfaceStore->getInterface(iid);
 }
+
+IThread* esCreateThread(void* (*start)(void* param), void* param)
+{
+    return new Thread(start, param, IThread::Normal);
+}
